# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/universe/space_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/universe/space_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.universe import quota_pb2 as eolymp_dot_universe_dot_quota__pb2
from eolymp.universe import space_pb2 as eolymp_dot_universe_dot_space__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/universe/space_service.proto\x12\x0f\x65olymp.universe\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1b\x65olymp/universe/quota.proto\x1a\x1b\x65olymp/universe/space.proto\x1a!eolymp/wellknown/expression.proto\"9\n\x10\x43reateSpaceInput\x12%\n\x05space\x18\x01 \x01(\x0b\x32\x16.eolymp.universe.Space\"%\n\x11\x43reateSpaceOutput\x12\x10\n\x08space_id\x18\x01 \x01(\t\"\xcd\x01\n\x10UpdateSpaceInput\x12\x36\n\x05patch\x18\x03 \x03(\x0e\x32\'.eolymp.universe.UpdateSpaceInput.Patch\x12\x10\n\x08space_id\x18\x01 \x01(\t\x12%\n\x05space\x18\x02 \x01(\x0b\x32\x16.eolymp.universe.Space\"H\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x07\n\x03KEY\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\t\n\x05IMAGE\x10\x03\x12\x08\n\x04TYPE\x10\x04\x12\x0e\n\nVISIBILITY\x10\x05\"\x13\n\x11UpdateSpaceOutput\"$\n\x10\x44\x65leteSpaceInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\"\x13\n\x11\x44\x65leteSpaceOutput\"M\n\x10LookupSpaceInput\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1c.eolymp.universe.Space.Extra\":\n\x11LookupSpaceOutput\x12%\n\x05space\x18\x01 \x01(\x0b\x32\x16.eolymp.universe.Space\"T\n\x12\x44\x65scribeSpaceInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\x12,\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1c.eolymp.universe.Space.Extra\"<\n\x13\x44\x65scribeSpaceOutput\x12%\n\x05space\x18\x01 \x01(\x0b\x32\x16.eolymp.universe.Space\"&\n\x12\x44\x65scribeQuotaInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\"<\n\x13\x44\x65scribeQuotaOutput\x12%\n\x05quota\x18\x01 \x01(\x0b\x32\x16.eolymp.universe.Quota\"K\n\x10UpdateQuotaInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\x12%\n\x05quota\x18\x02 \x01(\x0b\x32\x16.eolymp.universe.Quota\"\x13\n\x11UpdateQuotaOutput\"\xeb\x02\n\x0fListSpacesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.universe.ListSpacesInput.Filter\x12,\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1c.eolymp.universe.Space.Extra\x1a\xd1\x01\n\x06\x46ilter\x12\r\n\x05query\x18\x64 \x01(\t\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12+\n\x03key\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12-\n\x03own\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"H\n\x10ListSpacesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.universe.Space2\xfa\x06\n\x0cSpaceService\x12\x83\x01\n\x0bLookupSpace\x12!.eolymp.universe.LookupSpaceInput\x1a\".eolymp.universe.LookupSpaceOutput\"-\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x18\x12\x16/spaces/__lookup/{key}\x12\x90\x01\n\x0b\x43reateSpace\x12!.eolymp.universe.CreateSpaceInput\x1a\".eolymp.universe.CreateSpaceOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\x82\xd3\xe4\x93\x02\t\"\x07/spaces\x12\x9b\x01\n\x0bUpdateSpace\x12!.eolymp.universe.UpdateSpaceInput\x1a\".eolymp.universe.UpdateSpaceOutput\"E\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\x82\xd3\xe4\x93\x02\x14\x1a\x12/spaces/{space_id}\x12\x9b\x01\n\x0b\x44\x65leteSpace\x12!.eolymp.universe.DeleteSpaceInput\x1a\".eolymp.universe.DeleteSpaceOutput\"E\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\x82\xd3\xe4\x93\x02\x14*\x12/spaces/{space_id}\x12\x85\x01\n\rDescribeSpace\x12#.eolymp.universe.DescribeSpaceInput\x1a$.eolymp.universe.DescribeSpaceOutput\")\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x14\x12\x12/spaces/{space_id}\x12\x8c\x01\n\nListSpaces\x12 .eolymp.universe.ListSpacesInput\x1a!.eolymp.universe.ListSpacesOutput\"9\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x17\x8a\xe3\n\x13universe:space:read\x82\xd3\xe4\x93\x02\t\x12\x07/spacesB3Z1github.com/eolymp/go-sdk/eolymp/universe;universeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.universe.space_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/universe;universe'
  _globals['_SPACESERVICE'].methods_by_name['LookupSpace']._loaded_options = None
  _globals['_SPACESERVICE'].methods_by_name['LookupSpace']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\030\022\026/spaces/__lookup/{key}'
  _globals['_SPACESERVICE'].methods_by_name['CreateSpace']._loaded_options = None
  _globals['_SPACESERVICE'].methods_by_name['CreateSpace']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\030\212\343\n\024universe:space:write\202\323\344\223\002\t\"\007/spaces'
  _globals['_SPACESERVICE'].methods_by_name['UpdateSpace']._loaded_options = None
  _globals['_SPACESERVICE'].methods_by_name['UpdateSpace']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\030\212\343\n\024universe:space:write\202\323\344\223\002\024\032\022/spaces/{space_id}'
  _globals['_SPACESERVICE'].methods_by_name['DeleteSpace']._loaded_options = None
  _globals['_SPACESERVICE'].methods_by_name['DeleteSpace']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\030\212\343\n\024universe:space:write\202\323\344\223\002\024*\022/spaces/{space_id}'
  _globals['_SPACESERVICE'].methods_by_name['DescribeSpace']._loaded_options = None
  _globals['_SPACESERVICE'].methods_by_name['DescribeSpace']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\024\022\022/spaces/{space_id}'
  _globals['_SPACESERVICE'].methods_by_name['ListSpaces']._loaded_options = None
  _globals['_SPACESERVICE'].methods_by_name['ListSpaces']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\027\212\343\n\023universe:space:read\202\323\344\223\002\t\022\007/spaces'
  _globals['_CREATESPACEINPUT']._serialized_start=248
  _globals['_CREATESPACEINPUT']._serialized_end=305
  _globals['_CREATESPACEOUTPUT']._serialized_start=307
  _globals['_CREATESPACEOUTPUT']._serialized_end=344
  _globals['_UPDATESPACEINPUT']._serialized_start=347
  _globals['_UPDATESPACEINPUT']._serialized_end=552
  _globals['_UPDATESPACEINPUT_PATCH']._serialized_start=480
  _globals['_UPDATESPACEINPUT_PATCH']._serialized_end=552
  _globals['_UPDATESPACEOUTPUT']._serialized_start=554
  _globals['_UPDATESPACEOUTPUT']._serialized_end=573
  _globals['_DELETESPACEINPUT']._serialized_start=575
  _globals['_DELETESPACEINPUT']._serialized_end=611
  _globals['_DELETESPACEOUTPUT']._serialized_start=613
  _globals['_DELETESPACEOUTPUT']._serialized_end=632
  _globals['_LOOKUPSPACEINPUT']._serialized_start=634
  _globals['_LOOKUPSPACEINPUT']._serialized_end=711
  _globals['_LOOKUPSPACEOUTPUT']._serialized_start=713
  _globals['_LOOKUPSPACEOUTPUT']._serialized_end=771
  _globals['_DESCRIBESPACEINPUT']._serialized_start=773
  _globals['_DESCRIBESPACEINPUT']._serialized_end=857
  _globals['_DESCRIBESPACEOUTPUT']._serialized_start=859
  _globals['_DESCRIBESPACEOUTPUT']._serialized_end=919
  _globals['_DESCRIBEQUOTAINPUT']._serialized_start=921
  _globals['_DESCRIBEQUOTAINPUT']._serialized_end=959
  _globals['_DESCRIBEQUOTAOUTPUT']._serialized_start=961
  _globals['_DESCRIBEQUOTAOUTPUT']._serialized_end=1021
  _globals['_UPDATEQUOTAINPUT']._serialized_start=1023
  _globals['_UPDATEQUOTAINPUT']._serialized_end=1098
  _globals['_UPDATEQUOTAOUTPUT']._serialized_start=1100
  _globals['_UPDATEQUOTAOUTPUT']._serialized_end=1119
  _globals['_LISTSPACESINPUT']._serialized_start=1122
  _globals['_LISTSPACESINPUT']._serialized_end=1485
  _globals['_LISTSPACESINPUT_FILTER']._serialized_start=1276
  _globals['_LISTSPACESINPUT_FILTER']._serialized_end=1485
  _globals['_LISTSPACESOUTPUT']._serialized_start=1487
  _globals['_LISTSPACESOUTPUT']._serialized_end=1559
  _globals['_SPACESERVICE']._serialized_start=1562
  _globals['_SPACESERVICE']._serialized_end=2452
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/result.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/judge/result.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.judge import medal_pb2 as eolymp_dot_judge_dot_medal__pb2
from eolymp.judge import score_pb2 as eolymp_dot_judge_dot_score__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x65olymp/judge/result.proto\x12\x0c\x65olymp.judge\x1a\x18\x65olymp/judge/medal.proto\x1a\x18\x65olymp/judge/score.proto\"\xf8\x01\n\x06Result\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x07 \x01(\t\x12\x12\n\ncontest_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\nunofficial\x18\x04 \x01(\x08\x12\x14\n\x0c\x64isqualified\x18\x0b \x01(\x08\x12\r\n\x05ghost\x18\t \x01(\x08\x12\"\n\x05medal\x18\x08 \x01(\x0e\x32\x13.eolymp.judge.Medal\x12\x0c\n\x04rank\x18\x05 \x01(\r\x12\x12\n\nrank_lower\x18\x06 \x01(\r\x12\"\n\x05score\x18\n \x01(\x0b\x32\x13.eolymp.judge.ScoreB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.result_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_RESULT']._serialized_start=96
  _globals['_RESULT']._serialized_end=344
# @@protoc_insertion_point(module_scope)



from .stats_pb2 import *
from .usage_pb2 import *
from .file_pb2 import *
from .generation_task_pb2 import *
from .evaluation_task_pb2 import *
from .stress_task_pb2 import *
from .interactor_pb2 import *
from .task_service_pb2 import *
from .generation_report_pb2 import *
from .evaluation_report_pb2 import *
from .script_pb2 import *
from .stress_report_pb2 import *
from .checker_pb2 import *
from .task_service_http import *



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/attachment_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/atlas/attachment_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import attachment_pb2 as eolymp_dot_atlas_dot_attachment__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/atlas/attachment_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1d\x65olymp/atlas/attachment.proto\x1a!eolymp/wellknown/expression.proto\"E\n\x15\x43reateAttachmentInput\x12,\n\nattachment\x18\x02 \x01(\x0b\x32\x18.eolymp.atlas.Attachment\"/\n\x16\x43reateAttachmentOutput\x12\x15\n\rattachment_id\x18\x01 \x01(\t\"\\\n\x15UpdateAttachmentInput\x12\x15\n\rattachment_id\x18\x02 \x01(\t\x12,\n\nattachment\x18\x03 \x01(\x0b\x32\x18.eolymp.atlas.Attachment\"\x18\n\x16UpdateAttachmentOutput\".\n\x15\x44\x65leteAttachmentInput\x12\x15\n\rattachment_id\x18\x02 \x01(\t\"\x18\n\x16\x44\x65leteAttachmentOutput\"\xe9\x01\n\x14ListAttachmentsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.atlas.ListAttachmentsInput.Filter\x12\x0f\n\x07version\x18\x64 \x01(\r\x1a\x66\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"O\n\x15ListAttachmentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.atlas.Attachment\"A\n\x17\x44\x65scribeAttachmentInput\x12\x15\n\rattachment_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"H\n\x18\x44\x65scribeAttachmentOutput\x12,\n\nattachment\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Attachment2\xe4\x06\n\x11\x41ttachmentService\x12\x9d\x01\n\x10\x43reateAttachment\x12#.eolymp.atlas.CreateAttachmentInput\x1a$.eolymp.atlas.CreateAttachmentOutput\">\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x0e\"\x0c/attachments\x12\xad\x01\n\x10UpdateAttachment\x12#.eolymp.atlas.UpdateAttachmentInput\x1a$.eolymp.atlas.UpdateAttachmentOutput\"N\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x1e\"\x1c/attachments/{attachment_id}\x12\xad\x01\n\x10\x44\x65leteAttachment\x12#.eolymp.atlas.DeleteAttachmentInput\x1a$.eolymp.atlas.DeleteAttachmentOutput\"N\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x1e*\x1c/attachments/{attachment_id}\x12\x99\x01\n\x0fListAttachments\x12\".eolymp.atlas.ListAttachmentsInput\x1a#.eolymp.atlas.ListAttachmentsOutput\"=\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x0e\x12\x0c/attachments\x12\xb2\x01\n\x12\x44\x65scribeAttachment\x12%.eolymp.atlas.DescribeAttachmentInput\x1a&.eolymp.atlas.DescribeAttachmentOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x1e\x12\x1c/attachments/{attachment_id}B-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.attachment_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_ATTACHMENTSERVICE'].methods_by_name['CreateAttachment']._loaded_options = None
  _globals['_ATTACHMENTSERVICE'].methods_by_name['CreateAttachment']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\016\"\014/attachments'
  _globals['_ATTACHMENTSERVICE'].methods_by_name['UpdateAttachment']._loaded_options = None
  _globals['_ATTACHMENTSERVICE'].methods_by_name['UpdateAttachment']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\036\"\034/attachments/{attachment_id}'
  _globals['_ATTACHMENTSERVICE'].methods_by_name['DeleteAttachment']._loaded_options = None
  _globals['_ATTACHMENTSERVICE'].methods_by_name['DeleteAttachment']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\036*\034/attachments/{attachment_id}'
  _globals['_ATTACHMENTSERVICE'].methods_by_name['ListAttachments']._loaded_options = None
  _globals['_ATTACHMENTSERVICE'].methods_by_name['ListAttachments']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\016\022\014/attachments'
  _globals['_ATTACHMENTSERVICE'].methods_by_name['DescribeAttachment']._loaded_options = None
  _globals['_ATTACHMENTSERVICE'].methods_by_name['DescribeAttachment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\036\022\034/attachments/{attachment_id}'
  _globals['_CREATEATTACHMENTINPUT']._serialized_start=220
  _globals['_CREATEATTACHMENTINPUT']._serialized_end=289
  _globals['_CREATEATTACHMENTOUTPUT']._serialized_start=291
  _globals['_CREATEATTACHMENTOUTPUT']._serialized_end=338
  _globals['_UPDATEATTACHMENTINPUT']._serialized_start=340
  _globals['_UPDATEATTACHMENTINPUT']._serialized_end=432
  _globals['_UPDATEATTACHMENTOUTPUT']._serialized_start=434
  _globals['_UPDATEATTACHMENTOUTPUT']._serialized_end=458
  _globals['_DELETEATTACHMENTINPUT']._serialized_start=460
  _globals['_DELETEATTACHMENTINPUT']._serialized_end=506
  _globals['_DELETEATTACHMENTOUTPUT']._serialized_start=508
  _globals['_DELETEATTACHMENTOUTPUT']._serialized_end=532
  _globals['_LISTATTACHMENTSINPUT']._serialized_start=535
  _globals['_LISTATTACHMENTSINPUT']._serialized_end=768
  _globals['_LISTATTACHMENTSINPUT_FILTER']._serialized_start=666
  _globals['_LISTATTACHMENTSINPUT_FILTER']._serialized_end=768
  _globals['_LISTATTACHMENTSOUTPUT']._serialized_start=770
  _globals['_LISTATTACHMENTSOUTPUT']._serialized_end=849
  _globals['_DESCRIBEATTACHMENTINPUT']._serialized_start=851
  _globals['_DESCRIBEATTACHMENTINPUT']._serialized_end=916
  _globals['_DESCRIBEATTACHMENTOUTPUT']._serialized_start=918
  _globals['_DESCRIBEATTACHMENTOUTPUT']._serialized_end=990
  _globals['_ATTACHMENTSERVICE']._serialized_start=993
  _globals['_ATTACHMENTSERVICE']._serialized_end=1861
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/runtime/language.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/runtime/language.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/runtime/language.proto\x12\x0e\x65olymp.runtime\"\xad\x01\n\x08Language\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x1d.eolymp.runtime.Language.Type\x12\x12\n\ndeprecated\x18\x0b \x01(\x08\"F\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x0f\n\x0bPROGRAMMING\x10\x01\x12\x07\n\x03SQL\x10\x03\x12\x06\n\x02ML\x10\x04\x12\n\n\x05OTHER\x10\xe7\x07\x42\x31Z/github.com/eolymp/go-sdk/eolymp/runtime;runtimeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.runtime.language_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/runtime;runtime'
  _globals['_LANGUAGE']._serialized_start=50
  _globals['_LANGUAGE']._serialized_end=223
  _globals['_LANGUAGE_TYPE']._serialized_start=153
  _globals['_LANGUAGE_TYPE']._serialized_end=223
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/worker/executor_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/worker/executor_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/worker/executor_service.proto\x12\reolymp.worker\"\xad\x01\n\x0f\x45xecuteJobInput\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\n \x01(\t\x12:\n\x06inputs\x18\x0b \x03(\x0b\x32*.eolymp.worker.ExecuteJobInput.InputsEntry\x1a-\n\x0bInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc0\x03\n\x10\x45xecuteJobUpdate\x12\x42\n\x08progress\x18\x01 \x01(\x0b\x32..eolymp.worker.ExecuteJobUpdate.ProgressUpdateH\x00\x12?\n\x07outputs\x18\x02 \x01(\x0b\x32,.eolymp.worker.ExecuteJobUpdate.OutputUpdateH\x00\x12=\n\x04logs\x18\x03 \x01(\x0b\x32-.eolymp.worker.ExecuteJobUpdate.LoggingUpdateH\x00\x1a\x31\n\x0eProgressUpdate\x12\x10\n\x08progress\x18\x01 \x01(\r\x12\r\n\x05total\x18\x02 \x01(\r\x1a\x8a\x01\n\x0cOutputUpdate\x12J\n\x07outputs\x18\x01 \x03(\x0b\x32\x39.eolymp.worker.ExecuteJobUpdate.OutputUpdate.OutputsEntry\x1a.\n\x0cOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x1e\n\rLoggingUpdate\x12\r\n\x05\x63hunk\x18\x01 \x01(\x0c\x42\x08\n\x06update2d\n\x0f\x45xecutorService\x12Q\n\nExecuteJob\x12\x1e.eolymp.worker.ExecuteJobInput\x1a\x1f.eolymp.worker.ExecuteJobUpdate\"\x00\x30\x01\x42/Z-github.com/eolymp/go-sdk/eolymp/worker;workerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.worker.executor_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/worker;worker'
  _globals['_EXECUTEJOBINPUT_INPUTSENTRY']._loaded_options = None
  _globals['_EXECUTEJOBINPUT_INPUTSENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTEJOBUPDATE_OUTPUTUPDATE_OUTPUTSENTRY']._loaded_options = None
  _globals['_EXECUTEJOBUPDATE_OUTPUTUPDATE_OUTPUTSENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTEJOBINPUT']._serialized_start=56
  _globals['_EXECUTEJOBINPUT']._serialized_end=229
  _globals['_EXECUTEJOBINPUT_INPUTSENTRY']._serialized_start=184
  _globals['_EXECUTEJOBINPUT_INPUTSENTRY']._serialized_end=229
  _globals['_EXECUTEJOBUPDATE']._serialized_start=232
  _globals['_EXECUTEJOBUPDATE']._serialized_end=680
  _globals['_EXECUTEJOBUPDATE_PROGRESSUPDATE']._serialized_start=448
  _globals['_EXECUTEJOBUPDATE_PROGRESSUPDATE']._serialized_end=497
  _globals['_EXECUTEJOBUPDATE_OUTPUTUPDATE']._serialized_start=500
  _globals['_EXECUTEJOBUPDATE_OUTPUTUPDATE']._serialized_end=638
  _globals['_EXECUTEJOBUPDATE_OUTPUTUPDATE_OUTPUTSENTRY']._serialized_start=592
  _globals['_EXECUTEJOBUPDATE_OUTPUTUPDATE_OUTPUTSENTRY']._serialized_end=638
  _globals['_EXECUTEJOBUPDATE_LOGGINGUPDATE']._serialized_start=640
  _globals['_EXECUTEJOBUPDATE_LOGGINGUPDATE']._serialized_end=670
  _globals['_EXECUTORSERVICE']._serialized_start=682
  _globals['_EXECUTORSERVICE']._serialized_end=782
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/annotations/ratelimit.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/annotations/ratelimit.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/annotations/ratelimit.proto\x12\neolymp.api\x1a google/protobuf/descriptor.proto\"-\n\tRateLimit\x12\x0f\n\x05limit\x18\xae\xac\x01 \x01(\x02\x12\x0f\n\x05\x62urst\x18\xaf\xac\x01 \x01(\x05:J\n\tratelimit\x12\x1e.google.protobuf.MethodOptions\x18\xad\xac\x01 \x01(\x0b\x32\x15.eolymp.api.RateLimitB9Z7github.com/eolymp/go-sdk/eolymp/annotations;annotationsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.annotations.ratelimit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/eolymp/go-sdk/eolymp/annotations;annotations'
  _globals['_RATELIMIT']._serialized_start=84
  _globals['_RATELIMIT']._serialized_end=129
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/executor/generation_task.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/executor/generation_task.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import script_pb2 as eolymp_dot_executor_dot_script__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/executor/generation_task.proto\x12\x0f\x65olymp.executor\x1a\x1c\x65olymp/executor/script.proto\"\xfe\x06\n\x0eGenerationTask\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x11\n\treference\x18\x02 \x01(\t\x12\x0e\n\x06origin\x18\x03 \x01(\t\x12?\n\x08metadata\x18\x05 \x03(\x0b\x32-.eolymp.executor.GenerationTask.MetadataEntry\x12\x11\n\trun_count\x18\x10 \x01(\r\x12\x1c\n\x14interactive_followup\x18\x11 \x01(\x08\x12+\n\ninteractor\x18\x19 \x01(\x0b\x32\x17.eolymp.executor.Script\x12*\n\tvalidator\x18\x1a \x01(\x0b\x32\x17.eolymp.executor.Script\x12(\n\x07scripts\x18\x16 \x03(\x0b\x32\x17.eolymp.executor.Script\x12\x31\n\x04runs\x18\n \x03(\x0b\x32#.eolymp.executor.GenerationTask.Run\x1a\x33\n\tGenerator\x12\x13\n\x0bscript_name\x18\x01 \x01(\t\x12\x11\n\targuments\x18\x02 \x03(\t\x1a\xa9\x03\n\x03Run\x12\x11\n\treference\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\r\x12\r\n\x05group\x18\x06 \x01(\r\x12\x0c\n\x04\x63ost\x18\x04 \x01(\x02\x12\x39\n\x03\x65nv\x18\x05 \x03(\x0b\x32,.eolymp.executor.GenerationTask.Run.EnvEntry\x12\x13\n\tinput_url\x18\x0c \x01(\tH\x00\x12\x17\n\rinput_content\x18\x0b \x01(\tH\x00\x12\x44\n\x0finput_generator\x18\r \x01(\x0b\x32).eolymp.executor.GenerationTask.GeneratorH\x00\x12\x14\n\nanswer_url\x18\x16 \x01(\tH\x01\x12\x18\n\x0e\x61nswer_content\x18\x15 \x01(\tH\x01\x12\x45\n\x10\x61nswer_generator\x18\x17 \x01(\x0b\x32).eolymp.executor.GenerationTask.GeneratorH\x01\x1a*\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x07\n\x05inputB\x08\n\x06\x61nswer\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x33Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.generation_task_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _globals['_GENERATIONTASK_RUN_ENVENTRY']._loaded_options = None
  _globals['_GENERATIONTASK_RUN_ENVENTRY']._serialized_options = b'8\001'
  _globals['_GENERATIONTASK_METADATAENTRY']._loaded_options = None
  _globals['_GENERATIONTASK_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GENERATIONTASK']._serialized_start=89
  _globals['_GENERATIONTASK']._serialized_end=983
  _globals['_GENERATIONTASK_GENERATOR']._serialized_start=455
  _globals['_GENERATIONTASK_GENERATOR']._serialized_end=506
  _globals['_GENERATIONTASK_RUN']._serialized_start=509
  _globals['_GENERATIONTASK_RUN']._serialized_end=934
  _globals['_GENERATIONTASK_RUN_ENVENTRY']._serialized_start=873
  _globals['_GENERATIONTASK_RUN_ENVENTRY']._serialized_end=915
  _globals['_GENERATIONTASK_METADATAENTRY']._serialized_start=936
  _globals['_GENERATIONTASK_METADATAENTRY']._serialized_end=983
# @@protoc_insertion_point(module_scope)



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Student(_message.Message):
    __slots__ = ("id", "url", "member_id", "inactive", "assign_all", "overall_progress", "overall_grade", "grades", "graded_at", "updated_at", "created_at", "cursor")
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_EXTRA: _ClassVar[Student.Extra]
        GRADES: _ClassVar[Student.Extra]
    UNKNOWN_EXTRA: Student.Extra
    GRADES: Student.Extra
    class Grade(_message.Message):
        __slots__ = ("module_id", "grade", "grade_automatic", "grade_override", "excused")
        MODULE_ID_FIELD_NUMBER: _ClassVar[int]
        GRADE_FIELD_NUMBER: _ClassVar[int]
        GRADE_AUTOMATIC_FIELD_NUMBER: _ClassVar[int]
        GRADE_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
        EXCUSED_FIELD_NUMBER: _ClassVar[int]
        module_id: str
        grade: int
        grade_automatic: int
        grade_override: int
        excused: bool
        def __init__(self, module_id: _Optional[str] = ..., grade: _Optional[int] = ..., grade_automatic: _Optional[int] = ..., grade_override: _Optional[int] = ..., excused: bool = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    INACTIVE_FIELD_NUMBER: _ClassVar[int]
    ASSIGN_ALL_FIELD_NUMBER: _ClassVar[int]
    OVERALL_PROGRESS_FIELD_NUMBER: _ClassVar[int]
    OVERALL_GRADE_FIELD_NUMBER: _ClassVar[int]
    GRADES_FIELD_NUMBER: _ClassVar[int]
    GRADED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CURSOR_FIELD_NUMBER: _ClassVar[int]
    id: str
    url: str
    member_id: str
    inactive: bool
    assign_all: bool
    overall_progress: float
    overall_grade: int
    grades: _containers.RepeatedCompositeFieldContainer[Student.Grade]
    graded_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    created_at: _timestamp_pb2.Timestamp
    cursor: str
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., member_id: _Optional[str] = ..., inactive: bool = ..., assign_all: bool = ..., overall_progress: _Optional[float] = ..., overall_grade: _Optional[int] = ..., grades: _Optional[_Iterable[_Union[Student.Grade, _Mapping]]] = ..., graded_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., cursor: _Optional[str] = ...) -> None: ...



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AccessKey(_message.Message):
    __slots__ = ("id", "name", "scope", "created_at", "expires_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    scope: str
    created_at: _timestamp_pb2.Timestamp
    expires_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., scope: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., expires_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/commerce/order.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/commerce/order.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.commerce import address_pb2 as eolymp_dot_commerce_dot_address__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/commerce/order.proto\x12\x0f\x65olymp.commerce\x1a\x1d\x65olymp/commerce/address.proto\"\x9e\x06\n\x05Order\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\treference\x18\x02 \x01(\t\x12-\n\x06status\x18\x03 \x01(\x0e\x32\x1d.eolymp.commerce.Order.Status\x12*\n\x05items\x18\n \x03(\x0b\x32\x1b.eolymp.commerce.Order.Item\x12\x31\n\x0f\x62illing_address\x18( \x01(\x0b\x32\x18.eolymp.commerce.Address\x12\x32\n\x10shipping_address\x18) \x01(\x0b\x32\x18.eolymp.commerce.Address\x12 \n\x18\x62illing_same_as_shipping\x18* \x01(\x08\x12\x10\n\x08\x63urrency\x18\x14 \x01(\t\x12\x14\n\x0ctotal_amount\x18\x15 \x01(\r\x12\x17\n\x0fshipping_amount\x18\x16 \x01(\r\x12\x17\n\x0f\x64iscount_amount\x18\x17 \x01(\r\x12\x12\n\ntax_amount\x18\x18 \x01(\r\x12\x10\n\x08tax_rate\x18\x19 \x01(\r\x12\x10\n\x08tax_note\x18\x1a \x01(\t\x12\x13\n\x0bgrand_total\x18\x1e \x01(\r\x1a\x8a\x02\n\x04Item\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x11\n\timage_url\x18\x05 \x01(\t\x12\x12\n\nproduct_id\x18\x02 \x01(\t\x12\x12\n\nvariant_id\x18\x03 \x01(\t\x12\x18\n\x10quantity_ordered\x18\n \x01(\r\x12\x1a\n\x12quantity_cancelled\x18\x0b \x01(\r\x12\x18\n\x10quantity_shipped\x18\x0c \x01(\r\x12\x19\n\x11quantity_returned\x18\r \x01(\r\x12\x13\n\x0bunit_amount\x18\x15 \x01(\r\x12\x14\n\x0ctotal_amount\x18\x16 \x01(\r\x12\x17\n\x0f\x64iscount_amount\x18\x17 \x01(\r\"^\n\x06Status\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0e\n\nPROCESSING\x10\x03\x12\x0c\n\x08\x43\x41NCELED\x10\x04\x12\x0b\n\x07SHIPPED\x10\x05\x42\x33Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.order_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _globals['_ORDER']._serialized_start=80
  _globals['_ORDER']._serialized_end=878
  _globals['_ORDER_ITEM']._serialized_start=516
  _globals['_ORDER_ITEM']._serialized_end=782
  _globals['_ORDER_STATUS']._serialized_start=784
  _globals['_ORDER_STATUS']._serialized_end=878
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/scoreboard.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/judge/scoreboard.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.judge import medal_pb2 as eolymp_dot_judge_dot_medal__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/judge/scoreboard.proto\x12\x0c\x65olymp.judge\x1a\x18\x65olymp/judge/medal.proto\"\x82\n\n\nScoreboard\x12,\n\x05modes\x18\n \x03(\x0e\x32\x1d.eolymp.judge.Scoreboard.Mode\x12.\n\x06rounds\x18\x0c \x03(\x0b\x32\x1e.eolymp.judge.Scoreboard.Round\x12\x30\n\x07\x63olumns\x18\x0b \x03(\x0b\x32\x1f.eolymp.judge.Scoreboard.Column\x1a\"\n\x05Round\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x1a\xbe\x02\n\x06\x43olumn\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x04type\x18\x02 \x01(\x0e\x32$.eolymp.judge.Scoreboard.Column.Type\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0f\n\x07\x63hoices\x18\n \x03(\t\x12\x10\n\x08sortable\x18\x14 \x01(\x08\x12\x12\n\nfilterable\x18\x15 \x01(\x08\"\xad\x01\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x0f\n\x0bROUND_SCORE\x10\x02\x12\x11\n\rPROBLEM_SCORE\x10\x03\x12\n\n\x06STRING\x10\n\x12\n\n\x06NUMBER\x10\x0b\x12\n\n\x06\x43HOICE\x10\x0c\x12\x08\n\x04\x44\x41TE\x10\r\x12\t\n\x05\x45MAIL\x10\x0e\x12\x0c\n\x08\x43HECKBOX\x10\x0f\x12\x0b\n\x07\x43OUNTRY\x10\x10\x12\n\n\x06REGION\x10\x11\x12\x0f\n\x0bINSTITUTION\x10\x12\x1a\xd1\x05\n\x03Row\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12\r\n\x05index\x18\n \x01(\r\x12\x0c\n\x04rank\x18\x0b \x01(\r\x12\x13\n\x0brank_length\x18\x0c \x01(\r\x12\r\n\x05score\x18\x14 \x01(\x02\x12\x0f\n\x07penalty\x18\x15 \x01(\x02\x12\x13\n\x0btie_breaker\x18\x16 \x01(\r\x12\x12\n\nunofficial\x18\x1e \x01(\x08\x12\x14\n\x0c\x64isqualified\x18\x1f \x01(\x08\x12\"\n\x05medal\x18  \x01(\x0e\x32\x13.eolymp.judge.Medal\x12\x32\n\x06values\x18\x32 \x03(\x0b\x32\".eolymp.judge.Scoreboard.Row.Value\x1a\xcb\x01\n\x05Value\x12\x11\n\tcolumn_id\x18\x01 \x01(\t\x12>\n\x0bround_score\x18\x0b \x01(\x0b\x32\'.eolymp.judge.Scoreboard.Row.RoundScoreH\x00\x12\x42\n\rproblem_score\x18\x0c \x01(\x0b\x32).eolymp.judge.Scoreboard.Row.ProblemScoreH\x00\x12\x10\n\x06string\x18\r \x01(\tH\x00\x12\x10\n\x06number\x18\x0e \x01(\tH\x00\x42\x07\n\x05value\x1a\x8f\x01\n\nRoundScore\x12\r\n\x05score\x18\x01 \x01(\x02\x12\x0f\n\x07penalty\x18\x02 \x01(\x02\x12\x13\n\x0btie_breaker\x18\x03 \x01(\r\x12\x12\n\nunofficial\x18\n \x01(\x08\x12\x14\n\x0c\x64isqualified\x18\x0b \x01(\x08\x12\"\n\x05medal\x18  \x01(\x0e\x32\x13.eolymp.judge.Medal\x1a\x62\n\x0cProblemScore\x12\r\n\x05score\x18\x01 \x01(\x02\x12\x0f\n\x07penalty\x18\x02 \x01(\x02\x12\x10\n\x08\x61ttempts\x18\x03 \x01(\r\x12\x12\n\npercentage\x18\x04 \x01(\x02\x12\x0c\n\x04time\x18\x05 \x01(\r\"+\n\x04Mode\x12\n\n\x06RESULT\x10\x00\x12\n\n\x06\x46ROZEN\x10\x01\x12\x0b\n\x07UPSOLVE\x10\x02\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.scoreboard_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_SCOREBOARD']._serialized_start=74
  _globals['_SCOREBOARD']._serialized_end=1356
  _globals['_SCOREBOARD_ROUND']._serialized_start=232
  _globals['_SCOREBOARD_ROUND']._serialized_end=266
  _globals['_SCOREBOARD_COLUMN']._serialized_start=269
  _globals['_SCOREBOARD_COLUMN']._serialized_end=587
  _globals['_SCOREBOARD_COLUMN_TYPE']._serialized_start=414
  _globals['_SCOREBOARD_COLUMN_TYPE']._serialized_end=587
  _globals['_SCOREBOARD_ROW']._serialized_start=590
  _globals['_SCOREBOARD_ROW']._serialized_end=1311
  _globals['_SCOREBOARD_ROW_VALUE']._serialized_start=862
  _globals['_SCOREBOARD_ROW_VALUE']._serialized_end=1065
  _globals['_SCOREBOARD_ROW_ROUNDSCORE']._serialized_start=1068
  _globals['_SCOREBOARD_ROW_ROUNDSCORE']._serialized_end=1211
  _globals['_SCOREBOARD_ROW_PROBLEMSCORE']._serialized_start=1213
  _globals['_SCOREBOARD_ROW_PROBLEMSCORE']._serialized_end=1311
  _globals['_SCOREBOARD_MODE']._serialized_start=1313
  _globals['_SCOREBOARD_MODE']._serialized_end=1356
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.commerce import order_pb2 as _order_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CancelOrderInput(_message.Message):
    __slots__ = ("order_id",)
    ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    order_id: str
    def __init__(self, order_id: _Optional[str] = ...) -> None: ...

class CancelOrderOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeOrderInput(_message.Message):
    __slots__ = ("order_id",)
    ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    order_id: str
    def __init__(self, order_id: _Optional[str] = ...) -> None: ...

class DescribeOrderOutput(_message.Message):
    __slots__ = ("order",)
    ORDER_FIELD_NUMBER: _ClassVar[int]
    order: _order_pb2.Order
    def __init__(self, order: _Optional[_Union[_order_pb2.Order, _Mapping]] = ...) -> None: ...

class ListOrdersInput(_message.Message):
    __slots__ = ("offset", "size", "search", "filters", "sort", "order")
    class Sortable(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        DEFAULT: _ClassVar[ListOrdersInput.Sortable]
    DEFAULT: ListOrdersInput.Sortable
    class Filter(_message.Message):
        __slots__ = ("id",)
        ID_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ...) -> None: ...
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    search: str
    filters: ListOrdersInput.Filter
    sort: ListOrdersInput.Sortable
    order: _direction_pb2.Direction
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., search: _Optional[str] = ..., filters: _Optional[_Union[ListOrdersInput.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListOrdersInput.Sortable, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ...) -> None: ...

class ListOrdersOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_order_pb2.Order]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_order_pb2.Order, _Mapping]]] = ...) -> None: ...



import datetime

from eolymp.atlas import submission_pb2 as _submission_pb2
from eolymp.atlas import testing_feedback_pb2 as _testing_feedback_pb2
from eolymp.atlas import testing_scoring_pb2 as _testing_scoring_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Submission(_message.Message):
    __slots__ = ("id", "url", "contest_id", "problem_id", "participant_id", "submitted_at", "deleted", "lang", "source", "source_url", "signature", "status", "verdict", "error", "error_url", "cost", "score", "percentage", "time_usage", "cpu_usage", "memory_usage", "resource_usage", "gen_ai_use_score", "groups", "cursor")
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NO_EXTRA: _ClassVar[Submission.Extra]
        SOURCE: _ClassVar[Submission.Extra]
        GROUPS: _ClassVar[Submission.Extra]
        RUNS: _ClassVar[Submission.Extra]
    NO_EXTRA: Submission.Extra
    SOURCE: Submission.Extra
    GROUPS: Submission.Extra
    RUNS: Submission.Extra
    class Run(_message.Message):
        __slots__ = ("id", "index", "test_id", "cost", "score", "wall_time_usage", "cpu_time_usage", "memory_usage", "status", "verdict")
        ID_FIELD_NUMBER: _ClassVar[int]
        INDEX_FIELD_NUMBER: _ClassVar[int]
        TEST_ID_FIELD_NUMBER: _ClassVar[int]
        COST_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        WALL_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
        CPU_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
        MEMORY_USAGE_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        VERDICT_FIELD_NUMBER: _ClassVar[int]
        id: str
        index: int
        test_id: str
        cost: float
        score: float
        wall_time_usage: int
        cpu_time_usage: int
        memory_usage: int
        status: _submission_pb2.Submission.Status
        verdict: _submission_pb2.Submission.Verdict
        def __init__(self, id: _Optional[str] = ..., index: _Optional[int] = ..., test_id: _Optional[str] = ..., cost: _Optional[float] = ..., score: _Optional[float] = ..., wall_time_usage: _Optional[int] = ..., cpu_time_usage: _Optional[int] = ..., memory_usage: _Optional[int] = ..., status: _Optional[_Union[_submission_pb2.Submission.Status, str]] = ..., verdict: _Optional[_Union[_submission_pb2.Submission.Verdict, str]] = ...) -> None: ...
    class Group(_message.Message):
        __slots__ = ("index", "testset_id", "status", "verdict", "dependencies", "cost", "score", "scoring_mode", "feedback_policy", "wall_time_usage", "cpu_time_usage", "memory_usage", "runs")
        INDEX_FIELD_NUMBER: _ClassVar[int]
        TESTSET_ID_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        VERDICT_FIELD_NUMBER: _ClassVar[int]
        DEPENDENCIES_FIELD_NUMBER: _ClassVar[int]
        COST_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        SCORING_MODE_FIELD_NUMBER: _ClassVar[int]
        FEEDBACK_POLICY_FIELD_NUMBER: _ClassVar[int]
        WALL_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
        CPU_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
        MEMORY_USAGE_FIELD_NUMBER: _ClassVar[int]
        RUNS_FIELD_NUMBER: _ClassVar[int]
        index: int
        testset_id: str
        status: _submission_pb2.Submission.Status
        verdict: _submission_pb2.Submission.Verdict
        dependencies: _containers.RepeatedScalarFieldContainer[int]
        cost: float
        score: float
        scoring_mode: _testing_scoring_pb2.ScoringMode
        feedback_policy: _testing_feedback_pb2.FeedbackPolicy
        wall_time_usage: int
        cpu_time_usage: int
        memory_usage: int
        runs: _containers.RepeatedCompositeFieldContainer[Submission.Run]
        def __init__(self, index: _Optional[int] = ..., testset_id: _Optional[str] = ..., status: _Optional[_Union[_submission_pb2.Submission.Status, str]] = ..., verdict: _Optional[_Union[_submission_pb2.Submission.Verdict, str]] = ..., dependencies: _Optional[_Iterable[int]] = ..., cost: _Optional[float] = ..., score: _Optional[float] = ..., scoring_mode: _Optional[_Union[_testing_scoring_pb2.ScoringMode, str]] = ..., feedback_policy: _Optional[_Union[_testing_feedback_pb2.FeedbackPolicy, str]] = ..., wall_time_usage: _Optional[int] = ..., cpu_time_usage: _Optional[int] = ..., memory_usage: _Optional[int] = ..., runs: _Optional[_Iterable[_Union[Submission.Run, _Mapping]]] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    SUBMITTED_AT_FIELD_NUMBER: _ClassVar[int]
    DELETED_FIELD_NUMBER: _ClassVar[int]
    LANG_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    SOURCE_URL_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    VERDICT_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    ERROR_URL_FIELD_NUMBER: _ClassVar[int]
    COST_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
    CPU_USAGE_FIELD_NUMBER: _ClassVar[int]
    MEMORY_USAGE_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_USAGE_FIELD_NUMBER: _ClassVar[int]
    GEN_AI_USE_SCORE_FIELD_NUMBER: _ClassVar[int]
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    CURSOR_FIELD_NUMBER: _ClassVar[int]
    id: str
    url: str
    contest_id: str
    problem_id: str
    participant_id: str
    submitted_at: _timestamp_pb2.Timestamp
    deleted: bool
    lang: str
    source: str
    source_url: str
    signature: str
    status: _submission_pb2.Submission.Status
    verdict: _submission_pb2.Submission.Verdict
    error: str
    error_url: str
    cost: float
    score: float
    percentage: float
    time_usage: int
    cpu_usage: int
    memory_usage: int
    resource_usage: float
    gen_ai_use_score: float
    groups: _containers.RepeatedCompositeFieldContainer[Submission.Group]
    cursor: str
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., contest_id: _Optional[str] = ..., problem_id: _Optional[str] = ..., participant_id: _Optional[str] = ..., submitted_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., deleted: bool = ..., lang: _Optional[str] = ..., source: _Optional[str] = ..., source_url: _Optional[str] = ..., signature: _Optional[str] = ..., status: _Optional[_Union[_submission_pb2.Submission.Status, str]] = ..., verdict: _Optional[_Union[_submission_pb2.Submission.Verdict, str]] = ..., error: _Optional[str] = ..., error_url: _Optional[str] = ..., cost: _Optional[float] = ..., score: _Optional[float] = ..., percentage: _Optional[float] = ..., time_usage: _Optional[int] = ..., cpu_usage: _Optional[int] = ..., memory_usage: _Optional[int] = ..., resource_usage: _Optional[float] = ..., gen_ai_use_score: _Optional[float] = ..., groups: _Optional[_Iterable[_Union[Submission.Group, _Mapping]]] = ..., cursor: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/l10n/localization_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/l10n/localization_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.l10n import term_pb2 as eolymp_dot_l10n_dot_term__pb2
from eolymp.l10n import translation_pb2 as eolymp_dot_l10n_dot_translation__pb2
from eolymp.l10n import translation_pair_pb2 as eolymp_dot_l10n_dot_translation__pair__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/l10n/localization_service.proto\x12\x0b\x65olymp.l10n\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x16\x65olymp/l10n/term.proto\x1a\x1d\x65olymp/l10n/translation.proto\x1a\"eolymp/l10n/translation_pair.proto\x1a!eolymp/wellknown/expression.proto\"2\n\x0f\x43reateTermInput\x12\x1f\n\x04term\x18\x01 \x01(\x0b\x32\x11.eolymp.l10n.Term\"#\n\x10\x43reateTermOutput\x12\x0f\n\x07term_id\x18\x01 \x01(\t\"4\n\x10ImportTermsInput\x12 \n\x05terms\x18\x01 \x03(\x0b\x32\x11.eolymp.l10n.Term\"[\n\x11ImportTermsOutput\x12\x15\n\rcreated_count\x18\x01 \x01(\x05\x12\x15\n\rupdated_count\x18\x02 \x01(\x05\x12\x18\n\x10\x64\x65precated_count\x18\x03 \x01(\x05\"\xe4\x03\n\x0eListTermsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x33\n\x07\x66ilters\x18( \x01(\x0b\x32\".eolymp.l10n.ListTermsInput.Filter\x1aY\n\x15\x45xpressionTranslation\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12\x30\n\x06status\x18\x03 \x01(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x1a\xa3\x02\n\x06\x46ilter\x12\r\n\x05query\x18\x64 \x01(\t\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x03key\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x33\n\x07message\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x30\n\x06status\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x46\n\x0btranslation\x18\x05 \x03(\x0b\x32\x31.eolymp.l10n.ListTermsInput.ExpressionTranslation\"B\n\x0fListTermsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12 \n\x05items\x18\x02 \x03(\x0b\x32\x11.eolymp.l10n.Term\"C\n\x0fUpdateTermInput\x12\x0f\n\x07term_id\x18\x01 \x01(\t\x12\x1f\n\x04term\x18\x02 \x01(\x0b\x32\x11.eolymp.l10n.Term\"\x12\n\x10UpdateTermOutput\"#\n\x10RestoreTermInput\x12\x0f\n\x07term_id\x18\x01 \x01(\t\"\x13\n\x11RestoreTermOutput\"%\n\x12\x44\x65precateTermInput\x12\x0f\n\x07term_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65precateTermOutput\"\"\n\x0f\x44\x65leteTermInput\x12\x0f\n\x07term_id\x18\x01 \x01(\t\"\x12\n\x10\x44\x65leteTermOutput\"$\n\x11\x44\x65scribeTermInput\x12\x0f\n\x07term_id\x18\x01 \x01(\t\"5\n\x12\x44\x65scribeTermOutput\x12\x1f\n\x04term\x18\x01 \x01(\x0b\x32\x11.eolymp.l10n.Term\"%\n\x0e\x41\x64\x64LocaleInput\x12\x13\n\x0blocale_code\x18\x01 \x01(\t\"\x11\n\x0f\x41\x64\x64LocaleOutput\"(\n\x11RemoveLocaleInput\x12\x13\n\x0blocale_code\x18\x01 \x01(\t\"\x14\n\x12RemoveLocaleOutput\"\xd0\x01\n\x10ListLocalesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x35\n\x07\x66ilters\x18( \x01(\x0b\x32$.eolymp.l10n.ListLocalesInput.Filter\x1ag\n\x06\x46ilter\x12,\n\x04\x63ode\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x05ready\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"\xc5\x01\n\x11ListLocalesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x34\n\x05items\x18\x02 \x03(\x0b\x32%.eolymp.l10n.ListLocalesOutput.Locale\x1ak\n\x06Locale\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\r\n\x05ready\x18\x02 \x01(\x08\x12\x18\n\x10translated_terms\x18\n \x01(\x05\x12\x15\n\rmissing_terms\x18\x0b \x01(\x05\x12\x13\n\x0btotal_terms\x18\x0c \x01(\x05\"T\n\x12TranslateTermInput\x12\x0f\n\x07term_id\x18\x01 \x01(\t\x12-\n\x0btranslation\x18\x02 \x01(\x0b\x32\x18.eolymp.l10n.Translation\"-\n\x13TranslateTermOutput\x12\x16\n\x0etranslation_id\x18\x01 \x01(\t\"\xd2\x02\n\x15ListTranslationsInput\x12\x0f\n\x07term_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.l10n.ListTranslationsInput.Filter\x1a\xcd\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x33\n\x07message\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x30\n\x06status\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06locale\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"P\n\x16ListTranslationsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.l10n.Translation\":\n\x17SuggestTranslationInput\x12\x0f\n\x07term_id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x02 \x01(\t\",\n\x18SuggestTranslationOutput\x12\x10\n\x08messages\x18\x01 \x03(\t\"p\n\x16UpdateTranslationInput\x12\x0f\n\x07term_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\x12-\n\x0btranslation\x18\x03 \x01(\x0b\x32\x18.eolymp.l10n.Translation\"\x19\n\x17UpdateTranslationOutput\"B\n\x17\x41pproveTranslationInput\x12\x0f\n\x07term_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\"\x1a\n\x18\x41pproveTranslationOutput\"A\n\x16RejectTranslationInput\x12\x0f\n\x07term_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\"\x19\n\x17RejectTranslationOutput\"A\n\x16\x44\x65leteTranslationInput\x12\x0f\n\x07term_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\"\x19\n\x17\x44\x65leteTranslationOutput\"+\n\x18\x44\x65scribeTranslationInput\x12\x0f\n\x07term_id\x18\x01 \x01(\t\"<\n\x19\x44\x65scribeTranslationOutput\x12\x1f\n\x04term\x18\x01 \x01(\x0b\x32\x11.eolymp.l10n.Term\"\xac\x01\n\x17ImportTranslationsInput\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12L\n\x0ctranslations\x18\x02 \x03(\x0b\x32\x36.eolymp.l10n.ImportTranslationsInput.TranslationsEntry\x1a\x33\n\x11TranslationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x18ImportTranslationsOutput\x12\x15\n\rcreated_count\x18\x01 \x01(\x05\")\n\x17\x45xportTranslationsInput\x12\x0e\n\x06locale\x18\x01 \x01(\t\"\x9e\x01\n\x18\x45xportTranslationsOutput\x12M\n\x0ctranslations\x18\x02 \x03(\x0b\x32\x37.eolymp.l10n.ExportTranslationsOutput.TranslationsEntry\x1a\x33\n\x11TranslationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8a\x04\n\x19ListTranslationPairsInput\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\n \x01(\x05\x12\x10\n\x06offset\x18\x0b \x01(\x05H\x00\x12\x0f\n\x05\x61\x66ter\x18\x0c \x01(\tH\x00\x12\x10\n\x06\x62\x65\x66ore\x18\r \x01(\tH\x00\x12>\n\x07\x66ilters\x18( \x01(\x0b\x32-.eolymp.l10n.ListTranslationPairsInput.Filter\x1a\xbf\x02\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12\x34\n\x08term_key\x18\n \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x35\n\x0bterm_status\x18\x0b \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12:\n\x0esource_message\x18\x14 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12<\n\x12translation_status\x18\x1e \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12?\n\x13translation_message\x18\x1f \x03(\x0b\x32\".eolymp.wellknown.ExpressionStringB\x08\n\x06\x63ursor\"j\n\x1aListTranslationPairsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x10\n\x08has_more\x18\x02 \x01(\x08\x12+\n\x05items\x18\x03 \x03(\x0b\x32\x1c.eolymp.l10n.TranslationPair2\x83\x1b\n\x13LocalizationService\x12\x7f\n\nCreateTerm\x12\x1c.eolymp.l10n.CreateTermInput\x1a\x1d.eolymp.l10n.CreateTermOutput\"4\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x13\x8a\xe3\n\x0fl10n:term:write\x82\xd3\xe4\x93\x02\x08\"\x06/terms\x12{\n\tListTerms\x12\x1b.eolymp.l10n.ListTermsInput\x1a\x1c.eolymp.l10n.ListTermsOutput\"3\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x12\x8a\xe3\n\x0el10n:term:read\x82\xd3\xe4\x93\x02\x08\x12\x06/terms\x12\x89\x01\n\nUpdateTerm\x12\x1c.eolymp.l10n.UpdateTermInput\x1a\x1d.eolymp.l10n.UpdateTermOutput\">\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x13\x8a\xe3\n\x0fl10n:term:write\x82\xd3\xe4\x93\x02\x12\x1a\x10/terms/{term_id}\x12\x94\x01\n\x0bRestoreTerm\x12\x1d.eolymp.l10n.RestoreTermInput\x1a\x1e.eolymp.l10n.RestoreTermOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x13\x8a\xe3\n\x0fl10n:term:write\x82\xd3\xe4\x93\x02\x1a\"\x18/terms/{term_id}/restore\x12\x9c\x01\n\rDeprecateTerm\x12\x1f.eolymp.l10n.DeprecateTermInput\x1a .eolymp.l10n.DeprecateTermOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x13\x8a\xe3\n\x0fl10n:term:write\x82\xd3\xe4\x93\x02\x1c\"\x1a/terms/{term_id}/deprecate\x12\x89\x01\n\nDeleteTerm\x12\x1c.eolymp.l10n.DeleteTermInput\x1a\x1d.eolymp.l10n.DeleteTermOutput\">\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x13\x8a\xe3\n\x0fl10n:term:write\x82\xd3\xe4\x93\x02\x12*\x10/terms/{term_id}\x12\x8e\x01\n\x0c\x44\x65scribeTerm\x12\x1e.eolymp.l10n.DescribeTermInput\x1a\x1f.eolymp.l10n.DescribeTermOutput\"=\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x12\x8a\xe3\n\x0el10n:term:read\x82\xd3\xe4\x93\x02\x12\x12\x10/terms/{term_id}\x12\x82\x01\n\x0bImportTerms\x12\x1d.eolymp.l10n.ImportTermsInput\x1a\x1e.eolymp.l10n.ImportTermsOutput\"4\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x13\x8a\xe3\n\x0fl10n:term:write\x82\xd3\xe4\x93\x02\x08\x1a\x06/terms\x12\x8e\x01\n\tAddLocale\x12\x1b.eolymp.l10n.AddLocaleInput\x1a\x1c.eolymp.l10n.AddLocaleOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x15\x8a\xe3\n\x11l10n:locale:write\x82\xd3\xe4\x93\x02\x18\x1a\x16/locales/{locale_code}\x12\x97\x01\n\x0cRemoveLocale\x12\x1e.eolymp.l10n.RemoveLocaleInput\x1a\x1f.eolymp.l10n.RemoveLocaleOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x15\x8a\xe3\n\x11l10n:locale:write\x82\xd3\xe4\x93\x02\x18*\x16/locales/{locale_code}\x12\x85\x01\n\x0bListLocales\x12\x1d.eolymp.l10n.ListLocalesInput\x1a\x1e.eolymp.l10n.ListLocalesOutput\"7\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x14\x8a\xe3\n\x10l10n:locale:read\x82\xd3\xe4\x93\x02\n\x12\x08/locales\x12\xa6\x01\n\rTranslateTerm\x12\x1f.eolymp.l10n.TranslateTermInput\x1a .eolymp.l10n.TranslateTermOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1a\x8a\xe3\n\x16l10n:translation:write\x82\xd3\xe4\x93\x02\x1f\"\x1d/terms/{term_id}/translations\x12\xaf\x01\n\x10ListTranslations\x12\".eolymp.l10n.ListTranslationsInput\x1a#.eolymp.l10n.ListTranslationsOutput\"R\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xc8\x41\xf8\xe2\n\xc8\x01\x82\xe3\n\x19\x8a\xe3\n\x15l10n:translation:read\x82\xd3\xe4\x93\x02\x1f\x12\x1d/terms/{term_id}/translations\x12\xc3\x01\n\x11\x44\x65leteTranslation\x12#.eolymp.l10n.DeleteTranslationInput\x1a$.eolymp.l10n.DeleteTranslationOutput\"c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1a\x8a\xe3\n\x16l10n:translation:write\x82\xd3\xe4\x93\x02\x30*./terms/{term_id}/translations/{translation_id}\x12\xbd\x01\n\x12SuggestTranslation\x12$.eolymp.l10n.SuggestTranslationInput\x1a%.eolymp.l10n.SuggestTranslationOutput\"Z\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xc8\x41\xf8\xe2\n\xc8\x01\x82\xe3\n\x19\x8a\xe3\n\x15l10n:translation:read\x82\xd3\xe4\x93\x02\'\x12%/terms/{term_id}/suggestions/{locale}\x12\xc3\x01\n\x11UpdateTranslation\x12#.eolymp.l10n.UpdateTranslationInput\x1a$.eolymp.l10n.UpdateTranslationOutput\"c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1a\x8a\xe3\n\x16l10n:translation:write\x82\xd3\xe4\x93\x02\x30\x1a./terms/{term_id}/translations/{translation_id}\x12\xce\x01\n\x12\x41pproveTranslation\x12$.eolymp.l10n.ApproveTranslationInput\x1a%.eolymp.l10n.ApproveTranslationOutput\"k\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1a\x8a\xe3\n\x16l10n:translation:write\x82\xd3\xe4\x93\x02\x38\"6/terms/{term_id}/translations/{translation_id}/approve\x12\xca\x01\n\x11RejectTranslation\x12#.eolymp.l10n.RejectTranslationInput\x1a$.eolymp.l10n.RejectTranslationOutput\"j\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1a\x8a\xe3\n\x16l10n:translation:write\x82\xd3\xe4\x93\x02\x37\"5/terms/{term_id}/translations/{translation_id}/reject\x12\xae\x01\n\x12ImportTranslations\x12$.eolymp.l10n.ImportTranslationsInput\x1a%.eolymp.l10n.ImportTranslationsOutput\"K\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1a\x8a\xe3\n\x16l10n:translation:write\x82\xd3\xe4\x93\x02\x18\x1a\x16/translations/{locale}\x12\xad\x01\n\x12\x45xportTranslations\x12$.eolymp.l10n.ExportTranslationsInput\x1a%.eolymp.l10n.ExportTranslationsOutput\"J\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x19\x8a\xe3\n\x15l10n:translation:read\x82\xd3\xe4\x93\x02\x18\x12\x16/translations/{locale}\x12\xb0\x01\n\x14ListTranslationPairs\x12&.eolymp.l10n.ListTranslationPairsInput\x1a\'.eolymp.l10n.ListTranslationPairsOutput\"G\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x19\x8a\xe3\n\x15l10n:translation:read\x82\xd3\xe4\x93\x02\x15\x12\x13/translate/{locale}B+Z)github.com/eolymp/go-sdk/eolymp/l10n;l10nb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.l10n.localization_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/l10n;l10n'
  _globals['_IMPORTTRANSLATIONSINPUT_TRANSLATIONSENTRY']._loaded_options = None
  _globals['_IMPORTTRANSLATIONSINPUT_TRANSLATIONSENTRY']._serialized_options = b'8\001'
  _globals['_EXPORTTRANSLATIONSOUTPUT_TRANSLATIONSENTRY']._loaded_options = None
  _globals['_EXPORTTRANSLATIONSOUTPUT_TRANSLATIONSENTRY']._serialized_options = b'8\001'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['CreateTerm']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['CreateTerm']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\023\212\343\n\017l10n:term:write\202\323\344\223\002\010\"\006/terms'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['ListTerms']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['ListTerms']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\022\212\343\n\016l10n:term:read\202\323\344\223\002\010\022\006/terms'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['UpdateTerm']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['UpdateTerm']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\023\212\343\n\017l10n:term:write\202\323\344\223\002\022\032\020/terms/{term_id}'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['RestoreTerm']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['RestoreTerm']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\023\212\343\n\017l10n:term:write\202\323\344\223\002\032\"\030/terms/{term_id}/restore'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['DeprecateTerm']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['DeprecateTerm']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\023\212\343\n\017l10n:term:write\202\323\344\223\002\034\"\032/terms/{term_id}/deprecate'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['DeleteTerm']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['DeleteTerm']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\023\212\343\n\017l10n:term:write\202\323\344\223\002\022*\020/terms/{term_id}'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['DescribeTerm']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['DescribeTerm']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\022\212\343\n\016l10n:term:read\202\323\344\223\002\022\022\020/terms/{term_id}'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['ImportTerms']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['ImportTerms']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\023\212\343\n\017l10n:term:write\202\323\344\223\002\010\032\006/terms'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['AddLocale']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['AddLocale']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\025\212\343\n\021l10n:locale:write\202\323\344\223\002\030\032\026/locales/{locale_code}'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['RemoveLocale']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['RemoveLocale']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\025\212\343\n\021l10n:locale:write\202\323\344\223\002\030*\026/locales/{locale_code}'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['ListLocales']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['ListLocales']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\024\212\343\n\020l10n:locale:read\202\323\344\223\002\n\022\010/locales'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['TranslateTerm']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['TranslateTerm']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\032\212\343\n\026l10n:translation:write\202\323\344\223\002\037\"\035/terms/{term_id}/translations'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['ListTranslations']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['ListTranslations']._serialized_options = b'\352\342\n\014\365\342\n\000\000\310A\370\342\n\310\001\202\343\n\031\212\343\n\025l10n:translation:read\202\323\344\223\002\037\022\035/terms/{term_id}/translations'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['DeleteTranslation']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['DeleteTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\032\212\343\n\026l10n:translation:write\202\323\344\223\0020*./terms/{term_id}/translations/{translation_id}'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['SuggestTranslation']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['SuggestTranslation']._serialized_options = b'\352\342\n\014\365\342\n\000\000\310A\370\342\n\310\001\202\343\n\031\212\343\n\025l10n:translation:read\202\323\344\223\002\'\022%/terms/{term_id}/suggestions/{locale}'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['UpdateTranslation']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['UpdateTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\032\212\343\n\026l10n:translation:write\202\323\344\223\0020\032./terms/{term_id}/translations/{translation_id}'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['ApproveTranslation']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['ApproveTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\032\212\343\n\026l10n:translation:write\202\323\344\223\0028\"6/terms/{term_id}/translations/{translation_id}/approve'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['RejectTranslation']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['RejectTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\032\212\343\n\026l10n:translation:write\202\323\344\223\0027\"5/terms/{term_id}/translations/{translation_id}/reject'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['ImportTranslations']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['ImportTranslations']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\032\212\343\n\026l10n:translation:write\202\323\344\223\002\030\032\026/translations/{locale}'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['ExportTranslations']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['ExportTranslations']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\031\212\343\n\025l10n:translation:read\202\323\344\223\002\030\022\026/translations/{locale}'
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['ListTranslationPairs']._loaded_options = None
  _globals['_LOCALIZATIONSERVICE'].methods_by_name['ListTranslationPairs']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\031\212\343\n\025l10n:translation:read\202\323\344\223\002\025\022\023/translate/{locale}'
  _globals['_CREATETERMINPUT']._serialized_start=280
  _globals['_CREATETERMINPUT']._serialized_end=330
  _globals['_CREATETERMOUTPUT']._serialized_start=332
  _globals['_CREATETERMOUTPUT']._serialized_end=367
  _globals['_IMPORTTERMSINPUT']._serialized_start=369
  _globals['_IMPORTTERMSINPUT']._serialized_end=421
  _globals['_IMPORTTERMSOUTPUT']._serialized_start=423
  _globals['_IMPORTTERMSOUTPUT']._serialized_end=514
  _globals['_LISTTERMSINPUT']._serialized_start=517
  _globals['_LISTTERMSINPUT']._serialized_end=1001
  _globals['_LISTTERMSINPUT_EXPRESSIONTRANSLATION']._serialized_start=618
  _globals['_LISTTERMSINPUT_EXPRESSIONTRANSLATION']._serialized_end=707
  _globals['_LISTTERMSINPUT_FILTER']._serialized_start=710
  _globals['_LISTTERMSINPUT_FILTER']._serialized_end=1001
  _globals['_LISTTERMSOUTPUT']._serialized_start=1003
  _globals['_LISTTERMSOUTPUT']._serialized_end=1069
  _globals['_UPDATETERMINPUT']._serialized_start=1071
  _globals['_UPDATETERMINPUT']._serialized_end=1138
  _globals['_UPDATETERMOUTPUT']._serialized_start=1140
  _globals['_UPDATETERMOUTPUT']._serialized_end=1158
  _globals['_RESTORETERMINPUT']._serialized_start=1160
  _globals['_RESTORETERMINPUT']._serialized_end=1195
  _globals['_RESTORETERMOUTPUT']._serialized_start=1197
  _globals['_RESTORETERMOUTPUT']._serialized_end=1216
  _globals['_DEPRECATETERMINPUT']._serialized_start=1218
  _globals['_DEPRECATETERMINPUT']._serialized_end=1255
  _globals['_DEPRECATETERMOUTPUT']._serialized_start=1257
  _globals['_DEPRECATETERMOUTPUT']._serialized_end=1278
  _globals['_DELETETERMINPUT']._serialized_start=1280
  _globals['_DELETETERMINPUT']._serialized_end=1314
  _globals['_DELETETERMOUTPUT']._serialized_start=1316
  _globals['_DELETETERMOUTPUT']._serialized_end=1334
  _globals['_DESCRIBETERMINPUT']._serialized_start=1336
  _globals['_DESCRIBETERMINPUT']._serialized_end=1372
  _globals['_DESCRIBETERMOUTPUT']._serialized_start=1374
  _globals['_DESCRIBETERMOUTPUT']._serialized_end=1427
  _globals['_ADDLOCALEINPUT']._serialized_start=1429
  _globals['_ADDLOCALEINPUT']._serialized_end=1466
  _globals['_ADDLOCALEOUTPUT']._serialized_start=1468
  _globals['_ADDLOCALEOUTPUT']._serialized_end=1485
  _globals['_REMOVELOCALEINPUT']._serialized_start=1487
  _globals['_REMOVELOCALEINPUT']._serialized_end=1527
  _globals['_REMOVELOCALEOUTPUT']._serialized_start=1529
  _globals['_REMOVELOCALEOUTPUT']._serialized_end=1549
  _globals['_LISTLOCALESINPUT']._serialized_start=1552
  _globals['_LISTLOCALESINPUT']._serialized_end=1760
  _globals['_LISTLOCALESINPUT_FILTER']._serialized_start=1657
  _globals['_LISTLOCALESINPUT_FILTER']._serialized_end=1760
  _globals['_LISTLOCALESOUTPUT']._serialized_start=1763
  _globals['_LISTLOCALESOUTPUT']._serialized_end=1960
  _globals['_LISTLOCALESOUTPUT_LOCALE']._serialized_start=1853
  _globals['_LISTLOCALESOUTPUT_LOCALE']._serialized_end=1960
  _globals['_TRANSLATETERMINPUT']._serialized_start=1962
  _globals['_TRANSLATETERMINPUT']._serialized_end=2046
  _globals['_TRANSLATETERMOUTPUT']._serialized_start=2048
  _globals['_TRANSLATETERMOUTPUT']._serialized_end=2093
  _globals['_LISTTRANSLATIONSINPUT']._serialized_start=2096
  _globals['_LISTTRANSLATIONSINPUT']._serialized_end=2434
  _globals['_LISTTRANSLATIONSINPUT_FILTER']._serialized_start=2229
  _globals['_LISTTRANSLATIONSINPUT_FILTER']._serialized_end=2434
  _globals['_LISTTRANSLATIONSOUTPUT']._serialized_start=2436
  _globals['_LISTTRANSLATIONSOUTPUT']._serialized_end=2516
  _globals['_SUGGESTTRANSLATIONINPUT']._serialized_start=2518
  _globals['_SUGGESTTRANSLATIONINPUT']._serialized_end=2576
  _globals['_SUGGESTTRANSLATIONOUTPUT']._serialized_start=2578
  _globals['_SUGGESTTRANSLATIONOUTPUT']._serialized_end=2622
  _globals['_UPDATETRANSLATIONINPUT']._serialized_start=2624
  _globals['_UPDATETRANSLATIONINPUT']._serialized_end=2736
  _globals['_UPDATETRANSLATIONOUTPUT']._serialized_start=2738
  _globals['_UPDATETRANSLATIONOUTPUT']._serialized_end=2763
  _globals['_APPROVETRANSLATIONINPUT']._serialized_start=2765
  _globals['_APPROVETRANSLATIONINPUT']._serialized_end=2831
  _globals['_APPROVETRANSLATIONOUTPUT']._serialized_start=2833
  _globals['_APPROVETRANSLATIONOUTPUT']._serialized_end=2859
  _globals['_REJECTTRANSLATIONINPUT']._serialized_start=2861
  _globals['_REJECTTRANSLATIONINPUT']._serialized_end=2926
  _globals['_REJECTTRANSLATIONOUTPUT']._serialized_start=2928
  _globals['_REJECTTRANSLATIONOUTPUT']._serialized_end=2953
  _globals['_DELETETRANSLATIONINPUT']._serialized_start=2955
  _globals['_DELETETRANSLATIONINPUT']._serialized_end=3020
  _globals['_DELETETRANSLATIONOUTPUT']._serialized_start=3022
  _globals['_DELETETRANSLATIONOUTPUT']._serialized_end=3047
  _globals['_DESCRIBETRANSLATIONINPUT']._serialized_start=3049
  _globals['_DESCRIBETRANSLATIONINPUT']._serialized_end=3092
  _globals['_DESCRIBETRANSLATIONOUTPUT']._serialized_start=3094
  _globals['_DESCRIBETRANSLATIONOUTPUT']._serialized_end=3154
  _globals['_IMPORTTRANSLATIONSINPUT']._serialized_start=3157
  _globals['_IMPORTTRANSLATIONSINPUT']._serialized_end=3329
  _globals['_IMPORTTRANSLATIONSINPUT_TRANSLATIONSENTRY']._serialized_start=3278
  _globals['_IMPORTTRANSLATIONSINPUT_TRANSLATIONSENTRY']._serialized_end=3329
  _globals['_IMPORTTRANSLATIONSOUTPUT']._serialized_start=3331
  _globals['_IMPORTTRANSLATIONSOUTPUT']._serialized_end=3380
  _globals['_EXPORTTRANSLATIONSINPUT']._serialized_start=3382
  _globals['_EXPORTTRANSLATIONSINPUT']._serialized_end=3423
  _globals['_EXPORTTRANSLATIONSOUTPUT']._serialized_start=3426
  _globals['_EXPORTTRANSLATIONSOUTPUT']._serialized_end=3584
  _globals['_EXPORTTRANSLATIONSOUTPUT_TRANSLATIONSENTRY']._serialized_start=3278
  _globals['_EXPORTTRANSLATIONSOUTPUT_TRANSLATIONSENTRY']._serialized_end=3329
  _globals['_LISTTRANSLATIONPAIRSINPUT']._serialized_start=3587
  _globals['_LISTTRANSLATIONPAIRSINPUT']._serialized_end=4109
  _globals['_LISTTRANSLATIONPAIRSINPUT_FILTER']._serialized_start=3780
  _globals['_LISTTRANSLATIONPAIRSINPUT_FILTER']._serialized_end=4099
  _globals['_LISTTRANSLATIONPAIRSOUTPUT']._serialized_start=4111
  _globals['_LISTTRANSLATIONPAIRSOUTPUT']._serialized_end=4217
  _globals['_LOCALIZATIONSERVICE']._serialized_start=4220
  _globals['_LOCALIZATIONSERVICE']._serialized_end=7679
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/testing_scoring.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/atlas/testing_scoring.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/atlas/testing_scoring.proto\x12\x0c\x65olymp.atlas*C\n\x0bScoringMode\x12\x0c\n\x08NO_SCORE\x10\x00\x12\x08\n\x04\x45\x41\x43H\x10\x01\x12\x07\n\x03\x41LL\x10\x02\x12\t\n\x05WORST\x10\x03\x12\x08\n\x04\x42\x45ST\x10\x04\x42-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.testing_scoring_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_SCORINGMODE']._serialized_start=52
  _globals['_SCORINGMODE']._serialized_end=119
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/l10n/project.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/l10n/project.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x65olymp/l10n/project.proto\x12\x0b\x65olymp.l10n\"i\n\x07Project\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x10\n\x08logo_url\x18\x03 \x01(\t\x12\x10\n\x08home_url\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\tB+Z)github.com/eolymp/go-sdk/eolymp/l10n;l10nb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.l10n.project_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/l10n;l10n'
  _globals['_PROJECT']._serialized_start=42
  _globals['_PROJECT']._serialized_end=147
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/printer/printer.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/printer/printer.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/printer/printer.proto\x12\x0e\x65olymp.printer\"\xa3\x01\n\x07Printer\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\x12.\n\x06status\x18\x05 \x01(\x0e\x32\x1e.eolymp.printer.Printer.Status\x12\x0c\n\x04name\x18\n \x01(\t\">\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07OFFLINE\x10\x01\x12\t\n\x05READY\x10\x02\x12\x08\n\x04\x42USY\x10\x03\x42\x31Z/github.com/eolymp/go-sdk/eolymp/printer;printerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.printer.printer_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/printer;printer'
  _globals['_PRINTER']._serialized_start=49
  _globals['_PRINTER']._serialized_end=212
  _globals['_PRINTER_STATUS']._serialized_start=150
  _globals['_PRINTER_STATUS']._serialized_end=212
# @@protoc_insertion_point(module_scope)



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Credit(_message.Message):
    __slots__ = ("id", "reference", "note", "active", "total_amount", "redeemed_amount", "granted_at", "expires_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    NOTE_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    TOTAL_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    REDEEMED_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    GRANTED_AT_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    reference: str
    note: str
    active: bool
    total_amount: int
    redeemed_amount: int
    granted_at: _timestamp_pb2.Timestamp
    expires_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., reference: _Optional[str] = ..., note: _Optional[str] = ..., active: bool = ..., total_amount: _Optional[int] = ..., redeemed_amount: _Optional[int] = ..., granted_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., expires_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/announcement_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/judge/announcement_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.judge import announcement_pb2 as eolymp_dot_judge_dot_announcement__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'eolymp/judge/announcement_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1f\x65olymp/judge/announcement.proto\x1a!eolymp/wellknown/expression.proto\"_\n\x17\x43reateAnnouncementInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x30\n\x0c\x61nnouncement\x18\x02 \x01(\x0b\x32\x1a.eolymp.judge.Announcement\"&\n\x18\x43reateAnnouncementOutput\x12\n\n\x02id\x18\x01 \x01(\t\"x\n\x17UpdateAnnouncementInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x17\n\x0f\x61nnouncement_id\x18\x02 \x01(\t\x12\x30\n\x0c\x61nnouncement\x18\x03 \x01(\x0b\x32\x1a.eolymp.judge.Announcement\"\x1a\n\x18UpdateAnnouncementOutput\"F\n\x17\x44\x65leteAnnouncementInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x17\n\x0f\x61nnouncement_id\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteAnnouncementOutput\"D\n\x15ReadAnnouncementInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x17\n\x0f\x61nnouncement_id\x18\x02 \x01(\t\"\x18\n\x16ReadAnnouncementOutput\"z\n\x19\x44\x65scribeAnnouncementInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x17\n\x0f\x61nnouncement_id\x18\x02 \x01(\t\x12\x30\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32 .eolymp.judge.Announcement.Extra\"N\n\x1a\x44\x65scribeAnnouncementOutput\x12\x30\n\x0c\x61nnouncement\x18\x01 \x01(\x0b\x32\x1a.eolymp.judge.Announcement\"N\n\x1f\x44\x65scribeAnnouncementStatusInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x17\n\x0f\x61nnouncement_id\x18\x02 \x01(\t\"3\n DescribeAnnouncementStatusOutput\x12\x0f\n\x07is_read\x18\x01 \x01(\x08\"\xa3\x02\n\x16ListAnnouncementsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12<\n\x07\x66ilters\x18( \x01(\x0b\x32+.eolymp.judge.ListAnnouncementsInput.Filter\x12\x30\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32 .eolymp.judge.Announcement.Extra\x1ag\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\x07is_read\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"S\n\x17ListAnnouncementsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12)\n\x05items\x18\x02 \x03(\x0b\x32\x1a.eolymp.judge.Announcement\"c\n\x16WatchAnnouncementInput\x12\x17\n\x0f\x61nnouncement_id\x18\x01 \x01(\t\x12\x30\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32 .eolymp.judge.Announcement.Extra\"K\n\x17WatchAnnouncementOutput\x12\x30\n\x0c\x61nnouncement\x18\x01 \x01(\x0b\x32\x1a.eolymp.judge.Announcement\"K\n\x17WatchAnnouncementsInput\x12\x30\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32 .eolymp.judge.Announcement.Extra\"\xcc\x01\n\x18WatchAnnouncementsOutput\x12;\n\x05\x65vent\x18\x01 \x01(\x0e\x32,.eolymp.judge.WatchAnnouncementsOutput.Event\x12\x30\n\x0c\x61nnouncement\x18\x02 \x01(\x0b\x32\x1a.eolymp.judge.Announcement\"A\n\x05\x45vent\x12\x11\n\rUNKNOWN_EVENT\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07UPDATED\x10\x02\x12\x0b\n\x07\x44\x45LETED\x10\x03\"\x1f\n\x1dWatchAnnouncementSummaryInput\"6\n\x1eWatchAnnouncementSummaryOutput\x12\x14\n\x0cunread_count\x18\x01 \x01(\r2\xbe\r\n\x13\x41nnouncementService\x12\xa5\x01\n\x12\x43reateAnnouncement\x12%.eolymp.judge.CreateAnnouncementInput\x1a&.eolymp.judge.CreateAnnouncementOutput\"@\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x10\"\x0e/announcements\x12\xb7\x01\n\x12UpdateAnnouncement\x12%.eolymp.judge.UpdateAnnouncementInput\x1a&.eolymp.judge.UpdateAnnouncementOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\"\" /announcements/{announcement_id}\x12\xb7\x01\n\x12\x44\x65leteAnnouncement\x12%.eolymp.judge.DeleteAnnouncementInput\x1a&.eolymp.judge.DeleteAnnouncementOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\"* /announcements/{announcement_id}\x12\xb5\x01\n\x10ReadAnnouncement\x12#.eolymp.judge.ReadAnnouncementInput\x1a$.eolymp.judge.ReadAnnouncementOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\'\"%/announcements/{announcement_id}/read\x12\xbc\x01\n\x14\x44\x65scribeAnnouncement\x12\'.eolymp.judge.DescribeAnnouncementInput\x1a(.eolymp.judge.DescribeAnnouncementOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\"\x12 /announcements/{announcement_id}\x12\xd5\x01\n\x1a\x44\x65scribeAnnouncementStatus\x12-.eolymp.judge.DescribeAnnouncementStatusInput\x1a..eolymp.judge.DescribeAnnouncementStatusOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02)\x12\'/announcements/{announcement_id}/status\x12\xa1\x01\n\x11ListAnnouncements\x12$.eolymp.judge.ListAnnouncementsInput\x1a%.eolymp.judge.ListAnnouncementsOutput\"?\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x10\x12\x0e/announcements\x12~\n\x11WatchAnnouncement\x12$.eolymp.judge.WatchAnnouncementInput\x1a%.eolymp.judge.WatchAnnouncementOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12\x81\x01\n\x12WatchAnnouncements\x12%.eolymp.judge.WatchAnnouncementsInput\x1a&.eolymp.judge.WatchAnnouncementsOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12\x93\x01\n\x18WatchAnnouncementSummary\x12+.eolymp.judge.WatchAnnouncementSummaryInput\x1a,.eolymp.judge.WatchAnnouncementSummaryOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.announcement_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_ANNOUNCEMENTSERVICE'].methods_by_name['CreateAnnouncement']._loaded_options = None
  _globals['_ANNOUNCEMENTSERVICE'].methods_by_name['CreateAnnouncement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\020\"\016/announcements'
  _globals['_ANNOUNCEMENTSERVICE'].methods_by_name['UpdateAnnouncement']._loaded_options = None
  _globals['_ANNOUNCEMENTSERVICE'].methods_by_name['UpdateAnnouncement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\"\" /announcements/{announcement_id}'
  _globals['_ANNOUNCEMENTSERVICE'].methods_by_name['DeleteAnnouncement']._loaded_options = None
  _globals['_ANNOUNCEMENTSERVICE'].methods_by_name['DeleteAnnouncement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\"* /announcements/{announcement_id}'
  _globals['_ANNOUNCEMENTSERVICE'].methods_by_name['ReadAnnouncement']._loaded_options = None
  _globals['_ANNOUNCEMENTSERVICE'].methods_by_name['ReadAnnouncement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\'\"%/announcements/{announcement_id}/read'
  _globals['_ANNOUNCEMENTSERVICE'].methods_by_name['DescribeAnnouncement']._loaded_options = None
  _globals['_ANNOUNCEMENTSERVICE'].methods_by_name['DescribeAnnouncement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\"\022 /announcements/{announcement_id}'
  _globals['_ANNOUNCEMENTSERVICE'].methods_by_name['DescribeAnnouncementStatus']._loaded_options = None
  _globals['_ANNOUNCEMENTSERVICE'].methods_by_name['DescribeAnnouncementStatus']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002)\022\'/announcements/{announcement_id}/status'
  _globals['_ANNOUNCEMENTSERVICE'].methods_by_name['ListAnnouncements']._loaded_options = None
  _globals['_ANNOUNCEMENTSERVICE'].methods_by_name['ListAnnouncements']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\020\022\016/announcements'
  _globals['_ANNOUNCEMENTSERVICE'].methods_by_name['WatchAnnouncement']._loaded_options = None
  _globals['_ANNOUNCEMENTSERVICE'].methods_by_name['WatchAnnouncement']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _globals['_ANNOUNCEMENTSERVICE'].methods_by_name['WatchAnnouncements']._loaded_options = None
  _globals['_ANNOUNCEMENTSERVICE'].methods_by_name['WatchAnnouncements']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _globals['_ANNOUNCEMENTSERVICE'].methods_by_name['WatchAnnouncementSummary']._loaded_options = None
  _globals['_ANNOUNCEMENTSERVICE'].methods_by_name['WatchAnnouncementSummary']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _globals['_CREATEANNOUNCEMENTINPUT']._serialized_start=224
  _globals['_CREATEANNOUNCEMENTINPUT']._serialized_end=319
  _globals['_CREATEANNOUNCEMENTOUTPUT']._serialized_start=321
  _globals['_CREATEANNOUNCEMENTOUTPUT']._serialized_end=359
  _globals['_UPDATEANNOUNCEMENTINPUT']._serialized_start=361
  _globals['_UPDATEANNOUNCEMENTINPUT']._serialized_end=481
  _globals['_UPDATEANNOUNCEMENTOUTPUT']._serialized_start=483
  _globals['_UPDATEANNOUNCEMENTOUTPUT']._serialized_end=509
  _globals['_DELETEANNOUNCEMENTINPUT']._serialized_start=511
  _globals['_DELETEANNOUNCEMENTINPUT']._serialized_end=581
  _globals['_DELETEANNOUNCEMENTOUTPUT']._serialized_start=583
  _globals['_DELETEANNOUNCEMENTOUTPUT']._serialized_end=609
  _globals['_READANNOUNCEMENTINPUT']._serialized_start=611
  _globals['_READANNOUNCEMENTINPUT']._serialized_end=679
  _globals['_READANNOUNCEMENTOUTPUT']._serialized_start=681
  _globals['_READANNOUNCEMENTOUTPUT']._serialized_end=705
  _globals['_DESCRIBEANNOUNCEMENTINPUT']._serialized_start=707
  _globals['_DESCRIBEANNOUNCEMENTINPUT']._serialized_end=829
  _globals['_DESCRIBEANNOUNCEMENTOUTPUT']._serialized_start=831
  _globals['_DESCRIBEANNOUNCEMENTOUTPUT']._serialized_end=909
  _globals['_DESCRIBEANNOUNCEMENTSTATUSINPUT']._serialized_start=911
  _globals['_DESCRIBEANNOUNCEMENTSTATUSINPUT']._serialized_end=989
  _globals['_DESCRIBEANNOUNCEMENTSTATUSOUTPUT']._serialized_start=991
  _globals['_DESCRIBEANNOUNCEMENTSTATUSOUTPUT']._serialized_end=1042
  _globals['_LISTANNOUNCEMENTSINPUT']._serialized_start=1045
  _globals['_LISTANNOUNCEMENTSINPUT']._serialized_end=1336
  _globals['_LISTANNOUNCEMENTSINPUT_FILTER']._serialized_start=1233
  _globals['_LISTANNOUNCEMENTSINPUT_FILTER']._serialized_end=1336
  _globals['_LISTANNOUNCEMENTSOUTPUT']._serialized_start=1338
  _globals['_LISTANNOUNCEMENTSOUTPUT']._serialized_end=1421
  _globals['_WATCHANNOUNCEMENTINPUT']._serialized_start=1423
  _globals['_WATCHANNOUNCEMENTINPUT']._serialized_end=1522
  _globals['_WATCHANNOUNCEMENTOUTPUT']._serialized_start=1524
  _globals['_WATCHANNOUNCEMENTOUTPUT']._serialized_end=1599
  _globals['_WATCHANNOUNCEMENTSINPUT']._serialized_start=1601
  _globals['_WATCHANNOUNCEMENTSINPUT']._serialized_end=1676
  _globals['_WATCHANNOUNCEMENTSOUTPUT']._serialized_start=1679
  _globals['_WATCHANNOUNCEMENTSOUTPUT']._serialized_end=1883
  _globals['_WATCHANNOUNCEMENTSOUTPUT_EVENT']._serialized_start=1818
  _globals['_WATCHANNOUNCEMENTSOUTPUT_EVENT']._serialized_end=1883
  _globals['_WATCHANNOUNCEMENTSUMMARYINPUT']._serialized_start=1885
  _globals['_WATCHANNOUNCEMENTSUMMARYINPUT']._serialized_end=1916
  _globals['_WATCHANNOUNCEMENTSUMMARYOUTPUT']._serialized_start=1918
  _globals['_WATCHANNOUNCEMENTSUMMARYOUTPUT']._serialized_end=1972
  _globals['_ANNOUNCEMENTSERVICE']._serialized_start=1975
  _globals['_ANNOUNCEMENTSERVICE']._serialized_end=3701
# @@protoc_insertion_point(module_scope)
